@@ -6,12 +6,24 @@ from .config import Config, cfg
 
 __all__ = ('perms', 'Permissions', 'generate_permission_files', 'permission_defaults')
 
+_global_perm_name = 'global'
+
+
+def _global_perm_group():
+    return {
+        'name': 'global',
+        'permissions': [],
+        'members': []
+    }
+
+
 permission_defaults = {
     'admin': {
         'name': 'admin',
         'permissions': ['*'],
         'members': [cfg.owner]
     },
+    _global_perm_name: _global_perm_group()
 }
 
 
@@ -31,14 +43,24 @@ class Permissions:
 
         self.channels[channel] = config
 
+        needs_save = False
         if channel not in config.data['admin']['members']:
             config.data['admin']['members'].append(channel)
+            needs_save = True
+
+        if _global_perm_name not in config.data:
+            config.data[_global_perm_name] = _global_perm_group()
+            needs_save = True
+
+        if needs_save:
             self.channels[channel].save()
 
     def iter_user_groups(self, channel: str, user: str):
         """yields all permission groups a user is in for a channel"""
         user = user.lower()
         yield from ((name, group) for name, group in self[channel] if user in group['members'])
+        global_group = self[channel][_global_perm_name]
+        yield _global_perm_name, global_group
 
     def iter_groups(self, channel: str):
         if channel in self:
@@ -52,6 +74,9 @@ class Permissions:
 
     def has_permission(self, channel: str, user: str, perm: str) -> bool:
         """checks if a user has a permission"""
+        if not perm:
+            return True
+
         user, perm = user.lower(), perm.lower()
         search = {perm, '*'}
         return user == cfg.owner or any(p in search for p in self.iter_user_permissions(channel, user))
@@ -146,34 +171,34 @@ class Permissions:
 
         return False
 
-    def add_member(self, channel: str, group: str, member: str):
-        group = group.lower()
-        g = self.get_group(channel, group)
+    def add_member(self, channel: str, group_name: str, member: str):
+        group_name = group_name.lower()
+        group = self.get_group(channel, group_name)
 
-        if not g:
+        if not group:
             return False
 
         member = member.lower()
 
-        if member not in g['members']:
-            g['members'].append(member)
+        if member not in group['members']:
+            group['members'].append(member)
             self[channel].save()
 
         return True
 
-    def delete_member(self, channel: str, group: str, member: str):
-        group = group.lower()
-        g = self.get_group(channel, group)
+    def delete_member(self, channel: str, group_name: str, member: str):
+        group_name = group_name.lower()
+        group = self.get_group(channel, group_name)
 
-        if not g:
+        if not group:
             return False
 
         member = member.lower()
 
-        if member not in g['members']:
+        if member not in group['members']:
             return False
 
-        g['members'].remove(member)
+        group['members'].remove(member)
         self[channel].save()
 
         return True
